@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.4.5
+version 0.4.6
 
 =head2 SYNOPSIS
 
@@ -73,13 +73,13 @@ use warnings;
 
 =head2 our VERSION
 
-    our $VERSION = '0.4.5'
+    our $VERSION = '0.4.6'
 
     This version number is updated automatically!
 
 =cut
 
-our $VERSION = '0.4.5';
+our $VERSION = '0.4.6';
 
 
 =head2 Internals
@@ -362,7 +362,7 @@ sub _inc {
         my @name = split(/\//, $_);
         # link 
         $out .= qq{<li>}; 
-        $out .= qq{<a href="$in{_inc_dir}/$_" };
+        $out .= qq{<a href="$in{url}/$_" };
         $out .= qq{title="$name[$#name]">};
         $out .= qq{$name[$#name]};
         $out .= qq{</a>};
@@ -389,6 +389,20 @@ sub _inc {
 
         my $out = $modules->_inc_dir( dir => "")
 
+        <a 
+            href="http://loclhost:20202/_inc_dir/home/ns21u2204/perl5/perlbrew/perls/perl-5.38.0/lib/5.38.0/x86_64-linux"
+            title="x86_64-linux"
+        >
+        x86_64-linux
+        </a>
+
+        <a 
+            href="http://CompanionUrl/_inc_dir/home/ns21u2204/p/perl/Perl-Modules-Companion/lib" 
+            title="lib"
+        >
+        lib
+        </a>
+
 =cut
 
 sub _inc_dir {
